pub struct ReserveConfig {
pub optimal_utilization_rate: u8,
pub loan_to_value_ratio: u8,
pub liquidation_bonus: u8,
pub liquidation_threshold: u8,
pub min_borrow_rate: u8,
pub optimal_borrow_rate: u8,
pub max_borrow_rate: u8,
pub fees: ReserveFees,
}Expand description
Reserve configuration values
Fields
optimal_utilization_rate: u8Optimal utilization rate, as a percentage
loan_to_value_ratio: u8Target ratio of the value of borrows to deposits, as a percentage 0 if use as collateral is disabled
liquidation_bonus: u8Bonus a liquidator gets when repaying part of an unhealthy obligation, as a percentage
liquidation_threshold: u8Loan to value ratio at which an obligation can be liquidated, as a percentage
min_borrow_rate: u8Min borrow APY
optimal_borrow_rate: u8Optimal (utilization) borrow APY
max_borrow_rate: u8Max borrow APY
fees: ReserveFeesProgram owner fees assessed, separate from gains due to interest accrual